package com.jqtx.windows.job;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.jqtx.infrastructure.oss.starter.config.OssUtils;
import com.jqtx.windows.component.CreditComponent;
import com.jqtx.windows.component.enums.ZNPostUrlEnum;
import com.jqtx.windows.component.model.CreditModel;
import com.jqtx.windows.component.model.ZyJsonResult;
import com.jqtx.windows.utils.AbcHttpClient;
import com.xxl.job.core.handler.annotation.XxlJob;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.time.DateFormatUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.Date;
import java.util.List;
import java.util.UUID;

@Component
@Slf4j
public class CreditThirdDataJob {
    @Autowired
    private CreditComponent creditComponent;

    @Autowired
    private AbcHttpClient abcHttpClient;

    @Autowired
    private OssUtils ossUtils;

    @XxlJob("creditThirdDataJob")
    public void run() {
        List<CreditModel> creditModels = creditComponent.getListModelByCreditThirdStatus("INIT");
        creditModels.parallelStream().forEach(c -> {
            JSONObject thirdCredit = new JSONObject();
            thirdCredit.put("reqNo", c.getOrderNo());
            thirdCredit.put("type", "01");
            ZyJsonResult zyJsonResult = abcHttpClient.postRequest(thirdCredit.toJSONString(), ZNPostUrlEnum.CREDIT_QUERY.getCode());
            JSONArray jsonArray = zyJsonResult.getExternalInfo();
            JSONObject thirdData = new JSONObject();
            log.info("jsonArray:[{}]",jsonArray);
            for (int i = 0; i < jsonArray.size(); i++) {
                JSONObject jsonObject = (JSONObject) jsonArray.get(i);
                log.info("dataSource:[{}],data:[{}]",jsonObject.getString("dataSource"),jsonObject.getJSONObject("data"));
                thirdData.put(jsonObject.getString("dataSource"),jsonObject.getJSONObject("data"));
            }
            StringBuffer filePath = new StringBuffer();

            filePath.append("zhenong").append("/").append(DateFormatUtils.format(new Date(), "yyyyMMdd")).append("/").append(c.getOrderNo()).append("/");
            String pdfFileName = c.getClientCell()+UUID.randomUUID();
            ossUtils.upStringObject(filePath+pdfFileName,thirdData.toString());
            CreditModel creditModel=new CreditModel();
            creditModel.setCreditThirdStatus("FINISHED");
            creditModel.setCreditThirdUrl(filePath+pdfFileName);
            creditComponent.updateByOrderNo(c.getOrderNo(),creditModel);
        });
    }


}
